==> remotable-plugins-plugin-0.6.978.jar: js/iframe-min/host-min.js <==
(function(e,b){var f=b.$,d=e._AP=e._AP||{},g=["status","statusText","responseText"],a=["Content-Type"],c=(b.EventQueue=b.EventQueue||[]);
d.create=d.create||function(l){var E=l.ns,h=f("#ap-"+E),B="embedded-"+E,j="channel-"+E,m=f("#"+B),t=l.width||"100%",D=l.height||"0",n=new Date().getTime(),q=!!l.dialog,p;
function A(F,G){G=f.extend(G||{},{moduleKey:E});
c.push({name:F,properties:G})
}function w(F){h.find(".ap-status").addClass("hidden");
h.find(".ap-"+F).removeClass("hidden")
}var v=setTimeout(function(){v=null;
w("load-timeout");
var F=h.find(".ap-load-timeout");
F.find("a.ap-btn-cancel").click(function(){w("load-error");
r.trigger(q?"ra.dialog.close":"ra.iframe.destroy")
});
C();
A("plugin.iframetimedout",{elapsed:new Date().getTime()-n})
},20000);
function y(){if(v){clearTimeout(v);
v=null
}}function s(){return r.data("ra.dialog.buttons")
}function o(F){return r.data("ra.dialog.buttons").getButton(F)
}var i=new easyXDM.Rpc({remote:l.src,container:B,channel:j,protocol:"1",props:{width:t,height:D}},{remote:{dialogMessage:{},setWorkflowConfigurationMessage:{}},local:{init:function(){if(!p){p=true;
y();
m.addClass("iframe-init");
var F=new Date().getTime()-n;
w("loaded");
C();
r.trigger("ra.iframe.init");
A("plugin.iframeinited",{elapsed:F})
}},resize:k(function(G,F){if(!q){f("iframe",m).css({width:G,height:F})
}}),fireEvent:function(G,F){A("p3.iframe."+G,F)
},getLocation:function(){return e.location.href
},getUser:function(){var F=b.Meta,G=F?F.get("remote-user-fullname"):null;
if(!G){G=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!G){G=f("a#user-menu-link").attr("title")
}return{fullName:G,id:l.userId}
},getTimeZone:function(){return l.data.timeZone
},getWorkflowConfiguration:function(F,G){G(f("#remoteWorkflowPostFunctionConfiguration-"+F).val())
},showMessage:function(H,G,F){if(f("#aui-message-bar").length===0){f.html("div").attr("id","aui-message-bar").prependTo("#details-module")
}f(".aui-message#"+H).remove();
b.messages.info({title:G,body:"<p>"+f("<div/>").text(F).html()+"<p>",id:H,closeable:false})
},clearMessage:function(F){f(".aui-message#"+F).remove()
},setDialogButtonEnabled:function(G,F){var H=o(G);
if(H){H.setEnabled(F)
}},isDialogButtonEnabled:function(F,H){var G=o(F);
H(G?G.isEnabled():void 0)
},request:function(K,L,J){var I=l.contextPath+K.url;
function F(N){var M={headers:{}};
f.each(g,function(P,O){M[O]=N[O]
});
f.each(a,function(P,O){M.headers[O]=N.getResponseHeader(O)
});
return M
}function H(M,O,N){L([M,O,F(N)])
}function G(N,O,M){J([F(N),O,M])
}f.ajax({url:I,type:K.type||"GET",data:K.data,dataType:"text",contentType:K.contentType,headers:{Accept:"*/*","AP-App-Key":l.appKey}}).then(H,G)
}}});
var r=m.parents(".ap-servlet-placeholder"),x=f("iframe",m);
function C(){var F=f(".ap-stats",h);
if(q){var G=r.parent().height();
x.parents(".ap-servlet-placeholder, .ap-container").height(G);
var H=x.parents(".ap-container").height(),I=H-F.outerHeight(true);
x.height(I);
m.height(I)
}F.removeClass("hidden")
}C();
function k(F,H){var G;
return function(){var I=this,K=[].slice.call(arguments);
function J(){G=null;
F.apply(I,K)
}if(G){clearTimeout(G)
}G=setTimeout(J,H||50)
}
}var u=s();
if(u){u.each(function(F,G){G.click(function(H,I){if(p){i.dialogMessage(F,I)
}else{I(true)
}})
})
}var z=false;
f(document).delegate("#add_submit","click",function(F){if(!z){F.preventDefault();
i.setWorkflowConfigurationMessage(function(G){if(G.valid){f("#remoteWorkflowPostFunctionConfiguration-"+G.uuid).val(G.value);
z=true;
f("#add_submit").click()
}})
}});
f(document).delegate("#update_submit","click",function(F){if(!z){F.preventDefault();
i.setWorkflowConfigurationMessage(function(G){if(G.valid){f("#remoteWorkflowPostFunctionConfiguration-"+G.uuid).val(G.value);
z=true;
f("#update_submit").click()
}})
}});
r.bind("ra.iframe.destroy",function(){i.destroy()
});
r.trigger("ra.iframe.create")
}
}(this,AJS));

==> remotable-plugins-plugin-0.6.1010.jar: js/iframe-min/host-min.js <==
(function(e,b){var f=b.$,d=e._AP=e._AP||{},g=["status","statusText","responseText"],a=["Content-Type"],c=(b.EventQueue=b.EventQueue||[]);
d.create=d.create||function(l){var E=l.ns,h=f("#ap-"+E),B="embedded-"+E,j="channel-"+E,m=f("#"+B),t=l.width||"100%",D=l.height||"0",n=new Date().getTime(),q=!!l.dialog,p;
function A(F,G){G=f.extend(G||{},{moduleKey:E});
c.push({name:F,properties:G})
}function w(F){h.find(".ap-status").addClass("hidden");
h.find(".ap-"+F).removeClass("hidden")
}var v=setTimeout(function(){v=null;
w("load-timeout");
var F=h.find(".ap-load-timeout");
F.find("a.ap-btn-cancel").click(function(){w("load-error");
r.trigger(q?"ra.dialog.close":"ra.iframe.destroy")
});
C();
A("plugin.iframetimedout",{elapsed:new Date().getTime()-n})
},20000);
function y(){if(v){clearTimeout(v);
v=null
}}function s(){return r.data("ra.dialog.buttons")
}function o(F){return r.data("ra.dialog.buttons").getButton(F)
}var i=new d._Rpc({remote:l.src,container:B,channel:j,protocol:"1",props:{width:t,height:D}},{remote:{dialogMessage:{},setWorkflowConfigurationMessage:{}},local:{init:function(){if(!p){p=true;
y();
m.addClass("iframe-init");
var F=new Date().getTime()-n;
w("loaded");
C();
r.trigger("ra.iframe.init");
A("plugin.iframeinited",{elapsed:F})
}},resize:k(function(G,F){if(!q){f("iframe",m).css({width:G,height:F})
}}),fireEvent:function(G,F){A("p3.iframe."+G,F)
},getLocation:function(){return e.location.href
},getUser:function(){var F=b.Meta,G=F?F.get("remote-user-fullname"):null;
if(!G){G=f("a#header-details-user-fullname, .user.ajs-menu-title, a#user").text()
}if(!G){G=f("a#user-menu-link").attr("title")
}return{fullName:G,id:l.userId}
},getTimeZone:function(){return l.data.timeZone
},getWorkflowConfiguration:function(F,G){G(f("#remoteWorkflowPostFunctionConfiguration-"+F).val())
},showMessage:function(H,G,F){if(f("#aui-message-bar").length===0){f.html("div").attr("id","aui-message-bar").prependTo("#details-module")
}f(".aui-message#"+H).remove();
b.messages.info({title:G,body:"<p>"+f("<div/>").text(F).html()+"<p>",id:H,closeable:false})
},clearMessage:function(F){f(".aui-message#"+F).remove()
},setDialogButtonEnabled:function(G,F){var H=o(G);
if(H){H.setEnabled(F)
}},isDialogButtonEnabled:function(F,H){var G=o(F);
H(G?G.isEnabled():void 0)
},request:function(K,L,J){var I=l.contextPath+K.url;
function F(N){var M={headers:{}};
f.each(g,function(P,O){M[O]=N[O]
});
f.each(a,function(P,O){M.headers[O]=N.getResponseHeader(O)
});
return M
}function H(M,O,N){L([M,O,F(N)])
}function G(N,O,M){J([F(N),O,M])
}f.ajax({url:I,type:K.type||"GET",data:K.data,dataType:"text",contentType:K.contentType,headers:{Accept:"*/*","AP-App-Key":l.appKey}}).then(H,G)
}}});
var r=m.parents(".ap-servlet-placeholder"),x=f("iframe",m);
function C(){var F=f(".ap-stats",h);
if(q){var G=r.parent().height();
x.parents(".ap-servlet-placeholder, .ap-container").height(G);
var H=x.parents(".ap-container").height(),I=H-F.outerHeight(true);
x.height(I);
m.height(I)
}F.removeClass("hidden")
}C();
function k(F,H){var G;
return function(){var I=this,K=[].slice.call(arguments);
function J(){G=null;
F.apply(I,K)
}if(G){clearTimeout(G)
}G=setTimeout(J,H||50)
}
}var u=s();
if(u){u.each(function(F,G){G.click(function(H,I){if(p){i.dialogMessage(F,I)
}else{I(true)
}})
})
}var z=false;
f(document).delegate("#add_submit","click",function(F){if(!z){F.preventDefault();
i.setWorkflowConfigurationMessage(function(G){if(G.valid){f("#remoteWorkflowPostFunctionConfiguration-"+G.uuid).val(G.value);
z=true;
f("#add_submit").click()
}})
}});
f(document).delegate("#update_submit","click",function(F){if(!z){F.preventDefault();
i.setWorkflowConfigurationMessage(function(G){if(G.valid){f("#remoteWorkflowPostFunctionConfiguration-"+G.uuid).val(G.value);
z=true;
f("#update_submit").click()
}})
}});
r.bind("ra.iframe.destroy",function(){i.destroy()
});
r.trigger("ra.iframe.create")
}
}(this,AJS));
